aa_sampleSizeSummary_overTime <-
function(FILEPATH,SAMPLESIZES,MEASURES,ATESTRESULTFILENAME,SUMMARYFILENAME,TIMEPOINTS)
{
	# CREATE A SUMMARY FILE FOR EACH TIMEPOINT
	for(n in 1:length(TIMEPOINTS))
	{
		TIMEPOINTANALYSED<-TIMEPOINTS[n]

		ATESTSFILENAME<-paste(ATESTRESULTFILENAME,"_",TIMEPOINTANALYSED,sep="")
		SUMMARYFILENAMEFULL<-paste(SUMMARYFILENAME,"_",TIMEPOINTANALYSED,sep="")

		aa_sampleSizeSummary(FILEPATH,SAMPLESIZES,MEASURES,ATESTSFILENAME,SUMMARYFILENAMEFULL)
	}

}

